@@ -349,6 +349,9 @@ class Connection:
     def get_pipe_entities_url(self, pipe_id):
         return self.get_pipe_url(pipe_id) + "/entities"
 
+    def get_pipe_log_url(self, pipe_id):
+        return self.get_pipe_url(pipe_id) + "/log"
+
     def get_pipe_metadata_url(self, pipe_id):
         return self.get_pipe_url(pipe_id) + "/metadata"
 
